@@ -61,8 +61,10 @@ LearnerClassifAvg = R6Class("LearnerClassifAvg", inherit = LearnerClassif,
       ps = ps(
         measure = p_uty(custom_check = check_class_or_character("MeasureClassif", mlr_measures), tags = "train"),
         optimizer = p_uty(custom_check = check_optimizer, tags = "train"),
-        log_level = p_uty(tags = "train",
-          function(x) check_string(x) %check||% check_integerish(x))
+        log_level = p_uty(
+          custom_check = crate(function(x) check_string(x) %check||% check_integerish(x), .parent = topenv()),
+          tags = "train"
+        )
       )
       ps$values = list(measure = "classif.ce", optimizer = "nloptr", log_level = "warn")
       super$initialize(
